@@ -17,7 +17,6 @@
 # along with pytest-dbfixtures.  If not, see <http://www.gnu.org/licenses/>.
 
 import os
-import shutil
 import importlib
 import subprocess
 
@@ -154,6 +153,17 @@ def mongodb(request, mongo_proc):
     return mongodb
 
 
+def get_rabbit_env(name):
+    return os.environ.get(name) or os.environ.get(name.split('RABBITMQ_')[1])
+
+
+def get_rabbit_path(name):
+    env = get_rabbit_env(name)
+    if not env or not path(env).exists():
+        return
+    return path(env)
+
+
 @pytest.fixture
 def rabbitmq(request):
     pika, config = try_import('pika', request)
@@ -161,6 +171,10 @@ def rabbitmq(request):
     rabbit_conf = request.config.getvalue('rabbit_conf')
     for line in open(rabbit_conf):
         name, value = line[:-1].split('=')
+        # for new versions of rabbitmq-server:
+        os.environ[name] = value
+        # for older versions of rabbitmq-server:
+        prefix, name = name.split('RABBITMQ_')
         os.environ[name] = value
 
     rabbit_executor = TCPCoordinatedExecutor(
@@ -168,22 +182,24 @@ def rabbitmq(request):
         config.rabbit.host,
         config.rabbit.port,
     )
+    base_path = get_rabbit_path('RABBITMQ_MNESIA_BASE')
 
     def stop_and_reset():
         rabbit_executor.stop()
-        shutil.rmtree(os.environ['RABBITMQ_MNESIA_BASE'])
+        base_path.rmtree()
     request.addfinalizer(stop_and_reset)
 
     rabbit_executor.start()
-    pid_file = os.path.join(os.environ['RABBITMQ_MNESIA_BASE'],
-                            os.environ['RABBITMQ_NODENAME'] + '.pid')
+
+    # wait
+    pid_file = base_path / get_rabbit_env('RABBITMQ_NODENAME') + '.pid'
     wait_cmd = config.rabbit.rabbit_ctl, '-q', 'wait', pid_file
     subprocess.Popen(wait_cmd).communicate()
 
     rabbit_params = pika.connection.ConnectionParameters(
         host=config.rabbit.host,
         port=config.rabbit.port,
-        connection_attempts=10,
+        connection_attempts=3,
         retry_delay=2,
     )
     rabbit_connection = pika.BlockingConnection(rabbit_params)
